==> smart-wx-api-20.2.2-sources.jar: net/guerlab/smart/wx/api/feign/FeignWxMaApi.java <==
package net.guerlab.smart.wx.api.feign;

import net.guerlab.smart.wx.api.feign.factory.FeignWxMaApiFallbackFactory;
import net.guerlab.smart.wx.core.domain.LoginResponse;
import net.guerlab.smart.wx.core.domain.MaEncryptedData;
import net.guerlab.web.result.Result;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 微信小程序服务接口
 *
 * @author guers
 */
@FeignClient(name = "wx-internal/inside/wx/ma", fallbackFactory = FeignWxMaApiFallbackFactory.class)
public interface FeignWxMaApi {

    /**
     * 换取token
     *
     * @param appId
     *         appId
     * @param code
     *         code
     * @return 微信用户
     */
    @GetMapping("/{appId}/login/{code}")
    Result<LoginResponse> login(@PathVariable("appId") String appId, @PathVariable("code") String code);

    /**
     * 注册用户
     *
     * @param appId
     *         appId
     * @param openId
     *         openId
     * @param encryptedData
     *         小程序加密信息请求
     * @return 微信用户
     */
    @PostMapping("/{appId}/register/{openId}")
    Result<LoginResponse> register(@PathVariable("appId") String appId, @PathVariable("openId") String openId,
            @RequestBody MaEncryptedData encryptedData);

    /**
     * 获取accessToken
     *
     * @param appId
     *         appId
     * @return accessToken
     */
    @GetMapping("/{appId}/accessToken")
    Result<String> getAccessToken(@PathVariable("appId") String appId);

    /**
     * 获取电话号码
     *
     * @param appId
     *         appId
     * @param openId
     *         openId
     * @param encryptedData
     *         小程序加密信息请求
     * @return 电话号码
     */
    @PostMapping("/{appId}/getPhoneNumber/{openId}")
    Result<String> getPhoneNumber(@PathVariable("appId") String appId, @PathVariable("openId") String openId,
            @RequestBody MaEncryptedData encryptedData);
}

==> smart-wx-api-21.0.0-sources.jar: net/guerlab/smart/wx/api/feign/FeignWxMaApi.java <==
/*
 * Copyright 2018-2021 guerlab.net and other contributors.
 *
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, Version 3 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.guerlab.smart.wx.api.feign;

import net.guerlab.smart.wx.api.feign.factory.FeignWxMaApiFallbackFactory;
import net.guerlab.smart.wx.core.domain.LoginResponse;
import net.guerlab.smart.wx.core.domain.MaEncryptedData;
import net.guerlab.web.result.Result;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 微信小程序服务接口
 *
 * @author guers
 */
@FeignClient(value = "wx-internal", path = "/inside/wx/ma", fallbackFactory = FeignWxMaApiFallbackFactory.class)
public interface FeignWxMaApi {

    /**
     * 换取token
     *
     * @param appId
     *         appId
     * @param code
     *         code
     * @return 微信用户
     */
    @GetMapping("/{appId}/login/{code}")
    Result<LoginResponse> login(@PathVariable("appId") String appId, @PathVariable("code") String code);

    /**
     * 注册用户
     *
     * @param appId
     *         appId
     * @param openId
     *         openId
     * @param encryptedData
     *         小程序加密信息请求
     * @return 微信用户
     */
    @PostMapping("/{appId}/register/{openId}")
    Result<LoginResponse> register(@PathVariable("appId") String appId, @PathVariable("openId") String openId, @RequestBody MaEncryptedData encryptedData);

    /**
     * 获取accessToken
     *
     * @param appId
     *         appId
     * @return accessToken
     */
    @GetMapping("/{appId}/accessToken")
    Result<String> getAccessToken(@PathVariable("appId") String appId);

    /**
     * 获取电话号码
     *
     * @param appId
     *         appId
     * @param openId
     *         openId
     * @param encryptedData
     *         小程序加密信息请求
     * @return 电话号码
     */
    @PostMapping("/{appId}/getPhoneNumber/{openId}")
    Result<String> getPhoneNumber(@PathVariable("appId") String appId, @PathVariable("openId") String openId, @RequestBody MaEncryptedData encryptedData);
}
